Enum tugger_code_signing::Signability [−][src]
pub enum Signability {
Signable(Signable),
Unsignable,
UnsignableMachoError(AppleCodesignError),
PlatformUnsupported(&'static str),
}Represents the results of a signability test.
Variants
Signable(Signable)A known entity which is signable.
The entity is not signable for undetermined reason.
UnsignableMachoError(AppleCodesignError)The entity is a Mach-O binary that cannot be signed.
PlatformUnsupported(&'static str)The entity is signable, but not from this platform. Details of the limitation are stored in a string.