Enum tugger_code_signing::Signable [−][src]
pub enum Signable {
WindowsFile(PathBuf),
WindowsData(Vec<u8>),
MachOFile(PathBuf, Vec<u8>),
MachOData(Vec<u8>),
AppleBundle(PathBuf),
}Represents a known, typed entity which is signable.
Variants
WindowsFile(PathBuf)A file that is signable on Windows.
Data that is signable on Windows.
TODO store a Cow.
A signable Mach-O file.
We have to obtain the Mach-O data as part of evaluating whether it is signable. So we keep a reference to it to avoid a re-read later.
Signable Mach-O data.
AppleBundle(PathBuf)An Apple bundle, persisted on the filesystem as a directory.
Implementations
impl Signable[src]
impl Signable[src]pub fn signing_methods(&self) -> SigningMethods[src]
pub fn signing_methods(&self) -> SigningMethods[src]Obtain signing methods that are supported.
pub fn is_signable(&self) -> bool[src]
pub fn is_signable(&self) -> bool[src]Whether we are capable of signing.
pub fn source_file(&self) -> Option<&Path>[src]
pub fn source_file(&self) -> Option<&Path>[src]Obtain the filesystem path of the signable entity, if it is backed by a file.
pub fn source_directory(&self) -> Option<&Path>[src]
pub fn source_directory(&self) -> Option<&Path>[src]Obtain the filesystem path of the signable directory, if it is backed by a directory.
pub fn destination_compatibility(
&self,
destination: &SigningDestination
) -> SigningDestinationCompatibility[src]
pub fn destination_compatibility(
&self,
destination: &SigningDestination
) -> SigningDestinationCompatibility[src]Resolves the compatibility for signing this entity to a given SigningDestination.